az_cli_logout: Azure CLI Logout

View source: R/credential-azure-cli.R

az_cli_logoutR Documentation

Azure CLI Logout

Description

Logs out from Azure CLI by removing all stored credentials and account information. This function runs ⁠az logout⁠.

Usage

az_cli_logout()

Details

After logging out, you will need to run az_cli_login() again to authenticate and use Azure CLI credentials.

Value

Invisibly returns NULL


azr documentation built on May 5, 2026, 1:08 a.m.