View source: R/credential-cached-token.R
| cached_token_credential_chain | R Documentation |
Creates the default chain of credentials to attempt for cached token retrieval. The credentials are tried in order until one returns a valid cached token. The default chain includes:
Authorization Code Credential - Cached tokens from browser-based authentication
Device Code Credential - Cached tokens from device code flow
Azure CLI Credential - Cached tokens from Azure CLI authentication
cached_token_credential_chain()
A credential_chain object containing the sequence of
credential providers to check for cached tokens.
CachedTokenCredential, credential_chain()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.