default_azure_config_dir: Get default Azure configuration directory

View source: R/defaults.R

default_azure_config_dirR Documentation

Get default Azure configuration directory

Description

Retrieves the Azure configuration directory from the AZURE_CONFIG_DIR environment variable, or falls back to the platform-specific default.

Usage

default_azure_config_dir()

Value

A character string with the Azure configuration directory path

Examples

default_azure_config_dir()

azr documentation built on Feb. 18, 2026, 1:07 a.m.