| default_azure_url | R Documentation |
Constructs Azure OAuth 2.0 endpoint URLs for a given tenant and authority host.
default_azure_url(
endpoint = NULL,
oauth_host = default_azure_host(),
tenant_id = default_azure_tenant_id()
)
endpoint |
A character string specifying which endpoint URL to return.
Must be one of: |
oauth_host |
A character string specifying the Azure authority host.
Defaults to |
tenant_id |
A character string specifying the tenant ID. Defaults to
|
If endpoint is specified, returns a character string with the URL.
If endpoint is NULL, returns a named list of all endpoint URLs.
# Get all URLs
default_azure_url()
# Get specific endpoint
default_azure_url("token")
# Custom tenant
default_azure_url("authorize", tenant_id = "my-tenant-id")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.