View source: R/default-credential.R
| default_credential_chain | R Documentation |
Creates the default chain of credentials to attempt during authentication. The credentials are tried in order until one successfully authenticates. The default chain includes:
Client Secret Credential - Uses client ID and secret
Authorization Code Credential - Interactive browser-based authentication
Azure CLI Credential - Uses credentials from Azure CLI
Device Code Credential - Interactive device code flow
default_credential_chain()
A credential_chain object containing the default sequence of
credential providers.
credential_chain(), get_token_provider()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.