Skip to content

Returns the default host used to construct Microsoft Graph API URLs (graph.microsoft.com).

Usage

default_graph_endpoint()

Value

A character string with the Microsoft Graph endpoint host.

Examples

default_graph_endpoint()
#> [1] "graph.microsoft.com"