Skip to content

Returns the default host used to construct Azure Log Analytics query URLs (api.loganalytics.io).

Usage

default_log_analytics_endpoint()

Value

A character string with the Log Analytics query endpoint host.

Examples

default_log_analytics_endpoint()
#> [1] "api.loganalytics.io"