default_msal_token_cache: Get default MSAL token cache path

View source: R/defaults.R

default_msal_token_cacheR Documentation

Get default MSAL token cache path

Description

Returns the path to the MSAL token cache file shared by the Azure CLI and Azure SDKs. Defaults to msal_token_cache.json inside the Azure config directory (see default_azure_config_dir()).

Usage

default_msal_token_cache()

Value

A character string with the path to the MSAL token cache file.

See Also

default_azure_config_dir(), write_msal_token()


azr documentation built on May 5, 2026, 1:08 a.m.