| default_non_auth | R Documentation |
A pass-through credential function that performs no authentication. This function returns the request object unchanged, allowing API calls to be made without adding any authentication headers or tokens.
default_non_auth(req)
req |
An |
The same httr2::request() object, unmodified
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.