View source: R/default-credential.R
| get_token | R Documentation |
Retrieves an authentication token using the default token provider. This is a convenience function that combines credential discovery and token acquisition in a single step.
get_token(
scope = NULL,
tenant_id = NULL,
client_id = NULL,
client_secret = NULL,
use_cache = "disk",
offline = TRUE,
chain = default_credential_chain()
)
scope |
Optional character string specifying the authentication scope. |
tenant_id |
Optional character string specifying the tenant ID for authentication. |
client_id |
Optional character string specifying the client ID for authentication. |
client_secret |
Optional character string specifying the client secret for authentication. |
use_cache |
Character string indicating the caching strategy. Defaults
to |
offline |
Logical. If |
chain |
A list of credential objects, where each element must inherit
from the |
An httr2::oauth_token() object.
get_token_provider(), get_request_authorizer()
# In non-interactive sessions, this function will return an error if the
# environment is not setup with valid credentials. And in an interactive session
# the user will be prompted to attempt one of the interactive authentication flows.
## Not run:
token <- get_token(
scope = "https://graph.microsoft.com/.default",
tenant_id = "my-tenant-id",
client_id = "my-client-id",
client_secret = "my-secret"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.