View source: R/credential-azure-cli.R
| az_cli_is_login | R Documentation |
Checks whether the user is currently logged in to Azure CLI by attempting to retrieve account information.
az_cli_is_login(timeout = 10L)
timeout |
A numeric value specifying the timeout in seconds for the
Azure CLI command. Defaults to |
A logical value: TRUE if the user is logged in, FALSE otherwise
## Not run:
# Check if logged in
if (az_cli_is_login()) {
message("User is logged in")
} else {
message("User is not logged in")
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.