Learn R Programming

azr (version 0.3.1)

az_cli_is_login: Check if User is Logged in to Azure CLI

Description

Checks whether the user is currently logged in to Azure CLI by attempting to retrieve account information.

Usage

az_cli_is_login(timeout = 10L)

Value

A logical value: TRUE if the user is logged in, FALSE otherwise

Arguments

timeout

A numeric value specifying the timeout in seconds for the Azure CLI command. Defaults to 10.