Skip to contents

Logs out from Azure CLI by removing all stored credentials and account information. This function runs az logout.

Usage

az_cli_logout()

Value

Invisibly returns NULL

Details

After logging out, you will need to run az_cli_login() again to authenticate and use Azure CLI credentials.