Learn R Programming

azr (version 0.3.1)

az_cli_logout: Azure CLI Logout

Description

Logs out from Azure CLI by removing all stored credentials and account information. This function runs az logout.

Usage

az_cli_logout()

Arguments

Value

Invisibly returns NULL

Details

After logging out, you will need to run az_cli_login() again to authenticate and use Azure CLI credentials.