View source: R/azure-storage-client.R
| azr_storage_client | R Documentation |
A convenience wrapper around api_storage_client that creates a configured client for Azure Data Lake Storage Gen2 (ADLS Gen2) REST API operations.
azr_storage_client(
storageaccount,
filesystem,
chain = default_credential_chain(),
tenant_id = default_azure_tenant_id(),
...
)
storageaccount |
A character string specifying the Azure Storage account name. |
filesystem |
A character string specifying the filesystem (container) name. |
chain |
A credential_chain instance for authentication. Defaults to
|
tenant_id |
A character string specifying the Azure tenant ID. Defaults to
|
... |
Additional arguments passed to the api_storage_client constructor. |
An api_storage_client object.
## Not run:
# Create a storage client with default credentials
storage <- azr_storage_client(
storageaccount = "mystorageaccount",
filesystem = "mycontainer"
)
# Create a storage client with a specific tenant
storage <- azr_storage_client(
storageaccount = "mystorageaccount",
filesystem = "mycontainer",
tenant_id = "00000000-0000-0000-0000-000000000000"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.