Learn R Programming

azr (version 0.3.1)

azr_storage_client: Create an Azure Storage Client

Description

A convenience wrapper around api_storage_client that creates a configured client for Azure Data Lake Storage Gen2 (ADLS Gen2) REST API operations.

Usage

azr_storage_client(
  storageaccount,
  filesystem,
  chain = default_credential_chain(),
  tenant_id = default_azure_tenant_id(),
  ...
)

Value

An api_storage_client object.

Arguments

storageaccount

A character string specifying the Azure Storage account name.

filesystem

A character string specifying the filesystem (container) name.

chain

A credential_chain instance for authentication. Defaults to default_credential_chain().

tenant_id

A character string specifying the Azure tenant ID. Defaults to default_azure_tenant_id(), which reads AZURE_TENANT_ID from the environment.

...

Additional arguments passed to the api_storage_client constructor.

Examples

Run this code
if (FALSE) {
# Create a storage client with default credentials
storage <- azr_storage_client(
  storageaccount = "mystorageaccount",
  filesystem = "mycontainer"
)

# Create a storage client with a specific tenant
storage <- azr_storage_client(
  storageaccount = "mystorageaccount",
  filesystem = "mycontainer",
  tenant_id = "00000000-0000-0000-0000-000000000000"
)
}

Run the code above in your browser using DataLab