Create Cached Token Credential Chain
Source:R/credential-cached-token.R
cached_token_credential_chain.RdCreates the default chain of credentials to attempt for cached token retrieval. The credentials are tried in order until one returns a valid cached token. The default chain includes:
Authorization Code Credential - Cached tokens from browser-based authentication
Device Code Credential - Cached tokens from device code flow
Azure CLI Credential - Cached tokens from Azure CLI authentication
Value
A credential_chain object containing the sequence of
credential providers to check for cached tokens.