credential_chain: Create Custom Credential Chain

View source: R/credential.R View source: R/default-credential.R

credential_chainR Documentation

Create Custom Credential Chain

Description

Creates a custom chain of credential providers to attempt during authentication. Credentials are tried in the order they are provided until one successfully authenticates. This allows you to customize the authentication flow beyond the default credential chain.

Usage

credential_chain(...)

Arguments

...

Named credential objects or credential classes. Each element should be a credential class (e.g., ClientSecretCredential) or an instantiated credential object that inherits from the Credential base class. The names are used for identification purposes.

Value

A credential_chain object containing the specified sequence of credential providers.

See Also

default_credential_chain(), get_token_provider()

Examples

# Create a custom chain with only non-interactive credentials
custom_chain <- credential_chain(
  client_secret = ClientSecretCredential,
  azure_cli = AzureCLICredential
)

# Use the custom chain to get a token
## Not run: 
token <- get_token(
  scope = "https://graph.microsoft.com/.default",
  chain = custom_chain
)

## End(Not run)


azr documentation built on Feb. 18, 2026, 1:07 a.m.