View source: R/credential.R View source: R/default-credential.R
| credential_chain | R Documentation |
Creates a custom chain of credential providers to attempt during authentication. Credentials are tried in the order they are provided until one successfully authenticates. This allows you to customize the authentication flow beyond the default credential chain.
credential_chain(...)
... |
Named credential objects or credential classes. Each element
should be a credential class (e.g., |
A credential_chain object containing the specified sequence
of credential providers.
default_credential_chain(), get_token_provider()
# Create a custom chain with only non-interactive credentials
custom_chain <- credential_chain(
client_secret = ClientSecretCredential,
azure_cli = AzureCLICredential
)
# Use the custom chain to get a token
## Not run:
token <- get_token(
scope = "https://graph.microsoft.com/.default",
chain = custom_chain
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.