R/defaults.R
default_graph_endpoint.Rd
Returns the default host used to construct Microsoft Graph API URLs (graph.microsoft.com).
graph.microsoft.com
default_graph_endpoint()
A character string with the Microsoft Graph endpoint host.
default_graph_endpoint() #> [1] "graph.microsoft.com"