Get default Azure Log Analytics query endpoint
Source:R/defaults.R
default_log_analytics_endpoint.RdReturns the default host used to construct Azure Log Analytics query URLs
(api.loganalytics.io).

R/defaults.R
default_log_analytics_endpoint.RdReturns the default host used to construct Azure Log Analytics query URLs
(api.loganalytics.io).