Skip to contents

Returns the path to the MSAL token cache file shared by the Azure CLI and Azure SDKs. Defaults to msal_token_cache.json inside the Azure config directory (see default_azure_config_dir()).

Usage

default_msal_token_cache()

Value

A character string with the path to the MSAL token cache file.