| default_msal_token_cache | R Documentation |
Returns the path to the MSAL token cache file shared by the Azure CLI and
Azure SDKs. Defaults to msal_token_cache.json inside the Azure config
directory (see default_azure_config_dir()).
default_msal_token_cache()
A character string with the path to the MSAL token cache file.
default_azure_config_dir(), write_msal_token()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.