Learn R Programming

azr (version 0.3.3)

default_msal_token_cache: Get default MSAL token cache path

Description

Returns the path to the MSAL token cache file shared by the Azure CLI and Azure SDKs. Defaults to msal_token_cache.json inside the Azure config directory (see default_azure_config_dir()).

Usage

default_msal_token_cache()

Arguments

Value

A character string with the path to the MSAL token cache file.

See Also

default_azure_config_dir(), write_msal_token()